@@ -1,6 +1,6 @@
 # coding: utf-8
 
-# (C) Copyright IBM Corp. 2021.
+# (C) Copyright IBM Corp. 2022.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# IBM OpenAPI SDK Code Generator Version: 3.39.0-748eb4ca-20210917-165907
+# IBM OpenAPI SDK Code Generator Version: 3.62.0-a2a22f95-20221115-162524
 
 """
 IAM Policy Management API
@@ -140,7 +140,7 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `PolicyList` object
         """
 
-        if account_id is None:
+        if not account_id:
             raise ValueError('account_id must be provided')
         headers = {'Accept-Language': accept_language}
         sdk_headers = get_sdk_headers(
@@ -163,6 +163,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         url = '/v1/policies'
@@ -198,9 +199,12 @@ class IamPolicyManagementV1(BaseService):
         group. The roles must be a subset of a service's or the platform's supported
         roles. The resource attributes must be a subset of a service's or the platform's
         supported attributes. The policy resource must include either the
-        **`serviceType`**, **`serviceName`**,  or **`resourceGroupId`** attribute and the
-        **`accountId`** attribute.` If the subject is a locked service-id, the request
-        will fail.
+        **`serviceType`**, **`serviceName`**, **`resourceGroupId`** or
+        **`service_group_id`** attribute and the **`accountId`** attribute.` The IAM
+        Services group (`IAM`) is a subset of account management services that includes
+        the IAM platform services IAM Identity, IAM Access Management, IAM Users
+        Management, IAM Groups, and future IAM services. If the subject is a locked
+        service-id, the request will fail.
         ### Authorization
         Authorization policies are supported by services on a case by case basis. Refer to
         service documentation to verify their support of authorization policies. To create
@@ -217,7 +221,7 @@ class IamPolicyManagementV1(BaseService):
         **`accountId`** attributes.
         ### Attribute Operators
         Currently, only the `stringEquals` and the `stringMatch` operators are available.
-        Resource attributes may support one or both operators.  For more information, see
+        Resource attributes may support one or both operators. For more information, see
         [how to assign access by using wildcards
         policies](https://cloud.ibm.com/docs/account?topic=account-wildcard).
         ### Attribute Validations
@@ -274,6 +278,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         url = '/v1/policies'
@@ -325,8 +330,8 @@ class IamPolicyManagementV1(BaseService):
         **`accountId`** attributes.
         ### Attribute Operators
         Currently, only the `stringEquals` and the `stringMatch` operators are available.
-        Resource attributes might support one or both operators.  For more information,
-        see [how to assign access by using wildcards
+        Resource attributes might support one or both operators. For more information, see
+        [how to assign access by using wildcards
         policies](https://cloud.ibm.com/docs/account?topic=account-wildcard).
         ### Attribute Validations
         Policy attribute values must be between 1 and 1,000 characters in length. If
@@ -351,9 +356,9 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `Policy` object
         """
 
-        if policy_id is None:
+        if not policy_id:
             raise ValueError('policy_id must be provided')
-        if if_match is None:
+        if not if_match:
             raise ValueError('if_match must be provided')
         if type is None:
             raise ValueError('type must be provided')
@@ -379,6 +384,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         path_param_keys = ['policy_id']
@@ -402,7 +408,7 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `Policy` object
         """
 
-        if policy_id is None:
+        if not policy_id:
             raise ValueError('policy_id must be provided')
         headers = {}
         sdk_headers = get_sdk_headers(
@@ -412,6 +418,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         path_param_keys = ['policy_id']
@@ -437,7 +444,7 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse
         """
 
-        if policy_id is None:
+        if not policy_id:
             raise ValueError('policy_id must be provided')
         headers = {}
         sdk_headers = get_sdk_headers(
@@ -447,6 +454,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
 
         path_param_keys = ['policy_id']
         path_param_values = self.encode_path_vars(policy_id)
@@ -476,9 +484,9 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `Policy` object
         """
 
-        if policy_id is None:
+        if not policy_id:
             raise ValueError('policy_id must be provided')
-        if if_match is None:
+        if not if_match:
             raise ValueError('if_match must be provided')
         headers = {'If-Match': if_match}
         sdk_headers = get_sdk_headers(
@@ -493,6 +501,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         path_param_keys = ['policy_id']
@@ -566,6 +575,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         url = '/v2/roles'
@@ -652,6 +662,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         url = '/v2/roles'
@@ -692,9 +703,9 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `CustomRole` object
         """
 
-        if role_id is None:
+        if not role_id:
             raise ValueError('role_id must be provided')
-        if if_match is None:
+        if not if_match:
             raise ValueError('if_match must be provided')
         headers = {'If-Match': if_match}
         sdk_headers = get_sdk_headers(
@@ -709,6 +720,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         path_param_keys = ['role_id']
@@ -732,7 +744,7 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `CustomRole` object
         """
 
-        if role_id is None:
+        if not role_id:
             raise ValueError('role_id must be provided')
         headers = {}
         sdk_headers = get_sdk_headers(
@@ -742,6 +754,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
         headers['Accept'] = 'application/json'
 
         path_param_keys = ['role_id']
@@ -765,7 +778,7 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse
         """
 
-        if role_id is None:
+        if not role_id:
             raise ValueError('role_id must be provided')
         headers = {}
         sdk_headers = get_sdk_headers(
@@ -775,6 +788,7 @@ class IamPolicyManagementV1(BaseService):
 
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+            del kwargs['headers']
 
         path_param_keys = ['role_id']
         path_param_values = self.encode_path_vars(role_id)
@@ -1089,11 +1103,11 @@ class Policy:
         if 'description' in _dict:
             args['description'] = _dict.get('description')
         if 'subjects' in _dict:
-            args['subjects'] = [PolicySubject.from_dict(x) for x in _dict.get('subjects')]
+            args['subjects'] = [PolicySubject.from_dict(v) for v in _dict.get('subjects')]
         if 'roles' in _dict:
-            args['roles'] = [PolicyRole.from_dict(x) for x in _dict.get('roles')]
+            args['roles'] = [PolicyRole.from_dict(v) for v in _dict.get('roles')]
         if 'resources' in _dict:
-            args['resources'] = [PolicyResource.from_dict(x) for x in _dict.get('resources')]
+            args['resources'] = [PolicyResource.from_dict(v) for v in _dict.get('resources')]
         if 'href' in _dict:
             args['href'] = _dict.get('href')
         if 'created_at' in _dict:
@@ -1123,11 +1137,29 @@ class Policy:
         if hasattr(self, 'description') and self.description is not None:
             _dict['description'] = self.description
         if hasattr(self, 'subjects') and self.subjects is not None:
-            _dict['subjects'] = [x.to_dict() for x in self.subjects]
+            subjects_list = []
+            for v in self.subjects:
+                if isinstance(v, dict):
+                    subjects_list.append(v)
+                else:
+                    subjects_list.append(v.to_dict())
+            _dict['subjects'] = subjects_list
         if hasattr(self, 'roles') and self.roles is not None:
-            _dict['roles'] = [x.to_dict() for x in self.roles]
+            roles_list = []
+            for v in self.roles:
+                if isinstance(v, dict):
+                    roles_list.append(v)
+                else:
+                    roles_list.append(v.to_dict())
+            _dict['roles'] = roles_list
         if hasattr(self, 'resources') and self.resources is not None:
-            _dict['resources'] = [x.to_dict() for x in self.resources]
+            resources_list = []
+            for v in self.resources:
+                if isinstance(v, dict):
+                    resources_list.append(v)
+                else:
+                    resources_list.append(v.to_dict())
+            _dict['resources'] = resources_list
         if hasattr(self, 'href') and getattr(self, 'href') is not None:
             _dict['href'] = getattr(self, 'href')
         if hasattr(self, 'created_at') and getattr(self, 'created_at') is not None:
@@ -1189,7 +1221,7 @@ class PolicyList:
         """Initialize a PolicyList object from a json dictionary."""
         args = {}
         if 'policies' in _dict:
-            args['policies'] = [Policy.from_dict(x) for x in _dict.get('policies')]
+            args['policies'] = [Policy.from_dict(v) for v in _dict.get('policies')]
         return cls(**args)
 
     @classmethod
@@ -1201,7 +1233,13 @@ class PolicyList:
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'policies') and self.policies is not None:
-            _dict['policies'] = [x.to_dict() for x in self.policies]
+            policies_list = []
+            for v in self.policies:
+                if isinstance(v, dict):
+                    policies_list.append(v)
+                else:
+                    policies_list.append(v.to_dict())
+            _dict['policies'] = policies_list
         return _dict
 
     def _to_dict(self):
@@ -1248,9 +1286,9 @@ class PolicyResource:
         """Initialize a PolicyResource object from a json dictionary."""
         args = {}
         if 'attributes' in _dict:
-            args['attributes'] = [ResourceAttribute.from_dict(x) for x in _dict.get('attributes')]
+            args['attributes'] = [ResourceAttribute.from_dict(v) for v in _dict.get('attributes')]
         if 'tags' in _dict:
-            args['tags'] = [ResourceTag.from_dict(x) for x in _dict.get('tags')]
+            args['tags'] = [ResourceTag.from_dict(v) for v in _dict.get('tags')]
         return cls(**args)
 
     @classmethod
@@ -1262,9 +1300,21 @@ class PolicyResource:
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'attributes') and self.attributes is not None:
-            _dict['attributes'] = [x.to_dict() for x in self.attributes]
+            attributes_list = []
+            for v in self.attributes:
+                if isinstance(v, dict):
+                    attributes_list.append(v)
+                else:
+                    attributes_list.append(v.to_dict())
+            _dict['attributes'] = attributes_list
         if hasattr(self, 'tags') and self.tags is not None:
-            _dict['tags'] = [x.to_dict() for x in self.tags]
+            tags_list = []
+            for v in self.tags:
+                if isinstance(v, dict):
+                    tags_list.append(v)
+                else:
+                    tags_list.append(v.to_dict())
+            _dict['tags'] = tags_list
         return _dict
 
     def _to_dict(self):
@@ -1378,7 +1428,7 @@ class PolicySubject:
         """Initialize a PolicySubject object from a json dictionary."""
         args = {}
         if 'attributes' in _dict:
-            args['attributes'] = [SubjectAttribute.from_dict(x) for x in _dict.get('attributes')]
+            args['attributes'] = [SubjectAttribute.from_dict(v) for v in _dict.get('attributes')]
         return cls(**args)
 
     @classmethod
@@ -1390,7 +1440,13 @@ class PolicySubject:
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'attributes') and self.attributes is not None:
-            _dict['attributes'] = [x.to_dict() for x in self.attributes]
+            attributes_list = []
+            for v in self.attributes:
+                if isinstance(v, dict):
+                    attributes_list.append(v)
+                else:
+                    attributes_list.append(v.to_dict())
+            _dict['attributes'] = attributes_list
         return _dict
 
     def _to_dict(self):
@@ -1671,11 +1727,11 @@ class RoleList:
         """Initialize a RoleList object from a json dictionary."""
         args = {}
         if 'custom_roles' in _dict:
-            args['custom_roles'] = [CustomRole.from_dict(x) for x in _dict.get('custom_roles')]
+            args['custom_roles'] = [CustomRole.from_dict(v) for v in _dict.get('custom_roles')]
         if 'service_roles' in _dict:
-            args['service_roles'] = [Role.from_dict(x) for x in _dict.get('service_roles')]
+            args['service_roles'] = [Role.from_dict(v) for v in _dict.get('service_roles')]
         if 'system_roles' in _dict:
-            args['system_roles'] = [Role.from_dict(x) for x in _dict.get('system_roles')]
+            args['system_roles'] = [Role.from_dict(v) for v in _dict.get('system_roles')]
         return cls(**args)
 
     @classmethod
@@ -1687,11 +1743,29 @@ class RoleList:
         """Return a json dictionary representing this model."""
         _dict = {}
         if hasattr(self, 'custom_roles') and self.custom_roles is not None:
-            _dict['custom_roles'] = [x.to_dict() for x in self.custom_roles]
+            custom_roles_list = []
+            for v in self.custom_roles:
+                if isinstance(v, dict):
+                    custom_roles_list.append(v)
+                else:
+                    custom_roles_list.append(v.to_dict())
+            _dict['custom_roles'] = custom_roles_list
         if hasattr(self, 'service_roles') and self.service_roles is not None:
-            _dict['service_roles'] = [x.to_dict() for x in self.service_roles]
+            service_roles_list = []
+            for v in self.service_roles:
+                if isinstance(v, dict):
+                    service_roles_list.append(v)
+                else:
+                    service_roles_list.append(v.to_dict())
+            _dict['service_roles'] = service_roles_list
         if hasattr(self, 'system_roles') and self.system_roles is not None:
-            _dict['system_roles'] = [x.to_dict() for x in self.system_roles]
+            system_roles_list = []
+            for v in self.system_roles:
+                if isinstance(v, dict):
+                    system_roles_list.append(v)
+                else:
+                    system_roles_list.append(v.to_dict())
+            _dict['system_roles'] = system_roles_list
         return _dict
 
     def _to_dict(self):
